@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -80,13 +80,13 @@ from .instructions.measurements import (
     HomodyneMeasurement,
     HeterodyneMeasurement,
     GeneraldyneMeasurement,
-    Sampling,
 )
 
 from .instructions.channels import (
     DeterministicGaussianChannel,
     Attenuator,
     Loss,
+    LossyInterferometer,
 )
 
 
@@ -140,7 +140,6 @@ __all__ = [
     "ControlledX",
     "ControlledZ",
     "Interferometer",
-    "Sampling",
     "Graph",
     # Measurements
     "ParticleNumberMeasurement",
@@ -152,6 +151,7 @@ __all__ = [
     "DeterministicGaussianChannel",
     "Attenuator",
     "Loss",
+    "LossyInterferometer",
 ]
 
-__version__ = "0.8.1"
+__version__ = "1.0.0"
