@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,9 +30,8 @@ from .probabilities import calculate_click_probability
 
 from piquasso.api.result import Result
 from piquasso.api.instruction import Instruction
-from piquasso.api.errors import InvalidInstruction
+from piquasso.api.exceptions import InvalidInstruction
 
-from piquasso._math.linalg import reduce_
 from piquasso._math.indices import get_operator_index, get_auxiliary_operator_index
 from piquasso._math.decompositions import decompose_to_pure_and_mixed
 
@@ -401,6 +400,8 @@ def _get_particle_number_choice(
 
     d = len(state)
 
+    is_displaced = state._is_displaced()
+
     B = -np.linalg.inv(state.Q_matrix)[d:, :d]
     alpha = state.complex_displacement[:d]
 
@@ -413,12 +414,13 @@ def _get_particle_number_choice(
     for n in possible_choices:
         occupation_numbers = previous_sample + (n,)
 
-        B_reduced = reduce_(B, reduce_on=occupation_numbers)
-        gamma_reduced = reduce_(gamma, reduce_on=occupation_numbers)
+        hafnian_value = (
+            state._config.loop_hafnian_function(B, gamma, occupation_numbers)
+            if is_displaced
+            else state._config.hafnian_function(B, occupation_numbers)
+        )
 
-        np.fill_diagonal(B_reduced, gamma_reduced)
-
-        weight = abs(state._config.loop_hafnian_function(B_reduced)) ** 2 / factorial(n)
+        weight = abs(hafnian_value) ** 2 / factorial(n)
         weights = np.append(weights, weight)
 
     weights /= np.sum(weights)
