@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ from piquasso._backends.sampling.state import SamplingState
 
 from piquasso._math.validations import all_natural
 
-from piquasso.api.errors import InvalidState
+from piquasso.api.exceptions import InvalidState
 from piquasso.api.result import Result
 from piquasso.api.instruction import Instruction
 
@@ -113,7 +113,37 @@ def loss(state: SamplingState, instruction: Instruction, shots: int) -> Result:
     return Result(state=state)
 
 
-def sampling(state: SamplingState, instruction: Instruction, shots: int) -> Result:
+def lossy_interferometer(
+    state: SamplingState, instruction: Instruction, shots: int
+) -> Result:
+    state.is_lossy = True
+
+    _apply_matrix_on_modes(
+        state=state,
+        matrix=instruction._all_params["matrix"],
+        modes=instruction.modes,
+    )
+
+    return Result(state=state)
+
+
+def particle_number_measurement(
+    state: SamplingState, instruction: Instruction, shots: int
+) -> Result:
+    """
+    Simulates a boson sampling using generalized Clifford & Clifford algorithm
+    from [Brod, Oszmaniec 2020] see
+    `this article <https://arxiv.org/pdf/1612.01199.pdf>`_ for more details.
+
+    This method assumes that initial_state is given in the second quantization
+    description (mode occupation). `theboss` module requires the input states to be
+    numpy arrays, therefore the state is prepared as accordingly.
+
+    Generalized Cliffords simulation strategy form [Brod, Oszmaniec 2020] was used
+    as it allows effective simulation of broader range of input states than original
+    algorithm.
+    """
+
     initial_state = np.array(state.initial_state)
     permanent_calculator = RyserGuanPermanentCalculator(
         matrix=state.interferometer, input_state=initial_state
