@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 import random
 from typing import Sequence
 
-from piquasso.api.errors import PiquassoException
+from piquasso.api.exceptions import PiquassoException
 
 
 def choose_from_cumulated_probabilities(cumulated_probabilities: Sequence) -> int:
