@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,10 +17,11 @@ import numpy as np
 
 from piquasso._math.linalg import is_positive_semidefinite, is_real_2n_by_2n
 from piquasso._math.symplectic import symplectic_form
+from piquasso._math.validations import all_in_interval
 
 from piquasso.core import _mixins
 
-from piquasso.api.errors import InvalidParameter
+from piquasso.api.exceptions import InvalidParameter
 from piquasso.api.instruction import Gate
 
 
@@ -147,7 +148,7 @@ class Loss(Gate, _mixins.ScalingMixin):
 
     Note:
         Currently, this instruction can only be used along with
-        :class:`~piquasso._backends.sampling.state.SamplingState`.
+        :class:`~piquasso._backends.sampling.simulator.SamplingSimulator`.
     """
 
     def __init__(self, transmissivity: np.ndarray) -> None:
@@ -176,3 +177,49 @@ class Loss(Gate, _mixins.ScalingMixin):
                 f"The channel {self} is not applicable to modes {self.modes} with the "
                 "specified parameters."
             )
+
+
+class LossyInterferometer(Gate):
+    """Applies a lossy interferometer (specified by a matrix) to the state.
+
+    The lossy interferometer matrix :math:`A` should have singular values in the
+    interval :math:`[0, 1]`.
+
+    Applying :class:`LossyInterferometer` with parameter :math:`A` on all modes is
+    equivalent to the following::
+
+        pq.Q() | pq.Interferometer(W) | pq.Loss(np.diag(D)) | pq.Interferometer(V)
+
+    where :math:`A = V D W`, :math:`V, W` are unitary matrices and :math:`D` a
+    diagonal matrix. The diagonal entries in :math:`D` are called the singular values.
+
+    Note that the :math:`W` and :math:`V` interferometer matrices and the vector
+    :math:`D` are the results of the singular value decomposition (SVD) of the
+    (possibly lossy) interferometer A.
+
+    Note:
+        Currently, this instruction can only be used along with
+        :class:`~piquasso._backends.sampling.simulator.SamplingSimulator`.
+
+    Raises:
+        InvalidParameter:
+            When the singular values are not in the interval :math:`[0, 1]`.
+    """
+
+    def __init__(self, matrix: np.ndarray) -> None:
+        """
+        Args:
+            matrix (numpy.ndarray): The matrix representing the lossy interferometer.
+        """
+
+        _, singular_values, _ = np.linalg.svd(matrix)
+
+        if not all_in_interval(singular_values, lower=0.0, upper=1.0):
+            raise InvalidParameter(
+                "The specified lossy interferometer matrix has singular values outside "
+                f"of the interval [0, 1]: 'singular_values={singular_values}'"
+            )
+
+        super().__init__(
+            params=dict(matrix=matrix),
+        )
