@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ ladder operators by linear gates could be expressed in the form
 
 .. math::
 
-    U \xi U^\dagger = S_{(c)} \xi + d,
+    U^\dagger \xi U = S_{(c)} \xi + d,
 
 where :math:`S_{(c)} \in \operatorname{Sp}(2d, \mathbb{R})`,
 :math:`d \in \mathbb{C}^{2d}`,
@@ -48,7 +48,7 @@ from scipy.optimize import root_scalar
 from scipy.linalg import block_diag
 
 from piquasso.api.instruction import Gate
-from piquasso.api.errors import InvalidParameter
+from piquasso.api.exceptions import InvalidParameter
 
 from piquasso._math.decompositions import takagi
 from piquasso._math.linalg import is_square, is_symmetric, is_invertible
@@ -57,7 +57,7 @@ from piquasso._math.symplectic import complex_symplectic_form, is_symplectic
 from piquasso.core import _mixins
 
 
-class _BogoliubovTransformation(Gate):
+class _GaussianGate(Gate):
     def __init__(
         self,
         *,
@@ -78,8 +78,8 @@ class _BogoliubovTransformation(Gate):
         )
 
 
-class _ScalableBogoliubovTransformation(
-    _BogoliubovTransformation,
+class _ScalableGaussianGate(
+    _GaussianGate,
     _mixins.ScalingMixin,
 ):
     ERROR_MESSAGE_TEMPLATE = (
@@ -127,13 +127,13 @@ class _ScalableBogoliubovTransformation(
             )
 
 
-class Interferometer(_BogoliubovTransformation):
+class Interferometer(_GaussianGate):
     r"""Applies a general interferometer gate.
 
     The general unitary operator can be written as
 
     .. math::
-        U = \exp \left (
+        I = \exp \left (
             i \sum_{i, j = 1}^d H_{i j} a_i^\dagger a_j
         \right ),
 
@@ -141,8 +141,8 @@ class Interferometer(_BogoliubovTransformation):
 
     .. math::
         U = \exp \left (
-            i H \right
-        ).
+            i H
+        \right ).
 
     The evolution of the ladder operators can be described by
 
@@ -169,13 +169,13 @@ class Interferometer(_BogoliubovTransformation):
         super().__init__(params=dict(matrix=matrix), passive_block=matrix)
 
 
-class Beamsplitter(_BogoliubovTransformation):
+class Beamsplitter(_GaussianGate):
     r"""Applies a beamsplitter gate.
 
     The general unitary operator can be written as
 
     .. math::
-        BS_{ij} (\theta, \phi) = \exp \left (
+        B_{ij} (\theta, \phi) = \exp \left (
             \theta e^{i \phi} a^\dagger_i a_j
             - \theta e^{- i \phi} a^\dagger_j a_i
         \right ).
@@ -194,13 +194,13 @@ class Beamsplitter(_BogoliubovTransformation):
     """
 
     def __init__(self, theta: float = 0.0, phi: float = np.pi / 4) -> None:
-        """
+        r"""
         Args:
             phi (float):
                 Phase angle of the beamsplitter.
                 (defaults to :math:`\phi = \pi/2` that gives a symmetric beamsplitter)
             theta (float):
-                The transmittivity angle of the beamsplitter.
+                The transmissivity angle of the beamsplitter.
                 (defaults to :math:`\theta=\pi/4` that gives a 50-50 beamsplitter)
         """
 
@@ -221,7 +221,7 @@ class Beamsplitter(_BogoliubovTransformation):
         )
 
 
-class Phaseshifter(_ScalableBogoliubovTransformation):
+class Phaseshifter(_ScalableGaussianGate):
     r"""Applies a rotation or a phaseshifter gate.
 
     The unitary operator corresponding to the phaseshifter gate on the :math:`i`-th mode
@@ -252,7 +252,7 @@ class Phaseshifter(_ScalableBogoliubovTransformation):
         )
 
 
-class MachZehnder(_BogoliubovTransformation):
+class MachZehnder(_GaussianGate):
     r"""Mach-Zehnder interferometer.
 
     The Mach-Zehnder interferometer is equivalent to
@@ -296,7 +296,7 @@ class MachZehnder(_BogoliubovTransformation):
         )
 
 
-class Fourier(_ScalableBogoliubovTransformation):
+class Fourier(_ScalableGaussianGate):
     r"""Applies a Fourier gate. It simply transforms the quadratures as follows:
 
     .. math::
@@ -327,7 +327,7 @@ class Fourier(_ScalableBogoliubovTransformation):
         super().__init__(passive_block=np.array([[1j]]))
 
 
-class GaussianTransform(_BogoliubovTransformation):
+class GaussianTransform(_GaussianGate):
     r"""Applies a Gaussian transformation gate.
 
     The symplectic representation of the Gaussian gate is
@@ -374,7 +374,7 @@ class GaussianTransform(_BogoliubovTransformation):
         )
 
 
-class Squeezing(_ScalableBogoliubovTransformation):
+class Squeezing(_ScalableGaussianGate):
     r"""Applies the squeezing gate.
 
     The unitary operator corresponding to the squeezing gate is
@@ -417,7 +417,7 @@ class Squeezing(_ScalableBogoliubovTransformation):
         )
 
 
-class QuadraticPhase(_ScalableBogoliubovTransformation):
+class QuadraticPhase(_ScalableGaussianGate):
     r"""Applies the quadratic phase instruction to the state.
 
     The unitary operator corresponding to the Fourier gate is
@@ -445,7 +445,7 @@ class QuadraticPhase(_ScalableBogoliubovTransformation):
         )
 
 
-class Squeezing2(_BogoliubovTransformation):
+class Squeezing2(_GaussianGate):
     r"""Applies the two-mode squeezing gate to the state.
 
     The unitary operator corresponding to the two-mode squeezing gate is
@@ -489,7 +489,7 @@ class Squeezing2(_BogoliubovTransformation):
         )
 
 
-class ControlledX(_BogoliubovTransformation):
+class ControlledX(_GaussianGate):
     r"""Applies the controlled X gate to the state.
 
     The unitary operator corresponding to the controlled X gate is
@@ -528,7 +528,7 @@ class ControlledX(_BogoliubovTransformation):
         )
 
 
-class ControlledZ(_BogoliubovTransformation):
+class ControlledZ(_GaussianGate):
     r"""Applies the controlled Z gate to the state.
 
     The unitary operator corresponding to the controlled Z gate is
@@ -567,7 +567,7 @@ class ControlledZ(_BogoliubovTransformation):
         )
 
 
-class Displacement(_ScalableBogoliubovTransformation):
+class Displacement(_ScalableGaussianGate):
     r"""Phase space displacement instruction.
 
     Evolves the ladder operators by
@@ -578,7 +578,7 @@ class Displacement(_ScalableBogoliubovTransformation):
             \alpha^*
         \end{bmatrix},
 
-    where :math:`\alpha \in \mathbb{C}^{d \times d}`.
+    where :math:`\alpha \in \mathbb{C}^{d}`.
 
     One must either specify :math:`\alpha` only, or the combination of :math:`r` and
     :math:`\phi`.
@@ -615,7 +615,7 @@ class Displacement(_ScalableBogoliubovTransformation):
         super().__init__(params=params, displacement_vector=alpha_)
 
 
-class PositionDisplacement(_ScalableBogoliubovTransformation):
+class PositionDisplacement(_ScalableGaussianGate):
     r"""Position displacement gate. It affects only the :math:`\hat{x}` quadrature.
 
     Note:
@@ -633,7 +633,7 @@ class PositionDisplacement(_ScalableBogoliubovTransformation):
         )
 
 
-class MomentumDisplacement(_ScalableBogoliubovTransformation):
+class MomentumDisplacement(_ScalableGaussianGate):
     r"""Momentum displacement gate. It only affects the :math:`\hat{p}` quadrature.
 
     Note:
@@ -652,17 +652,17 @@ class MomentumDisplacement(_ScalableBogoliubovTransformation):
 
 
 class _ScalableFockGates(Gate, _mixins.ScalingMixin):
+    ERROR_MESSAGE_TEMPLATE = (
+        "The instruction {instruction} is not applicable to modes {modes} with the "
+        "specified parameters."
+    )
+
     def __init__(
         self, *, params: dict = None, gamma: np.ndarray = None, xi: np.ndarray = None
     ):
         params = params or {}
         super().__init__(params=params, extra_params=dict(gamma=gamma, xi=xi))
 
-    ERROR_MESSAGE_TEMPLATE = (
-        "The instruction {instruction} is not applicable to modes {modes} with the "
-        "specified parameters."
-    )
-
     def _autoscale(self) -> None:
         gamma = self._extra_params["gamma"]
         xi = self._extra_params["xi"]
@@ -736,7 +736,7 @@ class Kerr(_ScalableFockGates):
     The Kerr gate transforms the annihilation operator as
 
     .. math::
-        K(\xi) a K(\xi) = a \exp(- i \xi (1 + 2 n)).
+        K(\xi) a K(\xi)^\dagger = a \exp(- i \xi (1 + 2 n)).
 
     Note:
         This is a non-linear gate, therefore it couldn't be used with
