@@ -1,5 +1,5 @@
 #
-# Copyright 2021 Budapest Quantum Computing Group
+# Copyright 2021-2022 Budapest Quantum Computing Group
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,7 +19,7 @@ import numpy as np
 
 from piquasso.core import _mixins
 from piquasso.api.instruction import Preparation
-from piquasso.api.errors import InvalidParameter, InvalidState
+from piquasso.api.exceptions import InvalidParameter, InvalidState
 
 from piquasso._math.validations import all_natural, all_real_and_positive
 
